pub trait MeanN<T> {
// Required method
fn mean(&self) -> Option<T>;
}Expand description
The Mean trait implements the calculation of a mean.
pub trait MeanN<T> {
// Required method
fn mean(&self) -> Option<T>;
}The Mean trait implements the calculation of a mean.